==> devops-client-java-1.0.3-sources.jar: io/alauda/devops/java/client/models/V1alpha1CodeRepositoryStatusBuilder.java <==
package io.alauda.devops.java.client.models;

import io.alauda.devops.java.client.fluent.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class V1alpha1CodeRepositoryStatusBuilder extends V1alpha1CodeRepositoryStatusFluentImpl<V1alpha1CodeRepositoryStatusBuilder> implements VisitableBuilder<V1alpha1CodeRepositoryStatus,V1alpha1CodeRepositoryStatusBuilder>{

    V1alpha1CodeRepositoryStatusFluent<?> fluent;
    Boolean validationEnabled;

    public V1alpha1CodeRepositoryStatusBuilder(){
            this(true);
    }
    public V1alpha1CodeRepositoryStatusBuilder(Boolean validationEnabled){
            this(new V1alpha1CodeRepositoryStatus(), validationEnabled);
    }
    public V1alpha1CodeRepositoryStatusBuilder(V1alpha1CodeRepositoryStatusFluent<?> fluent){
            this(fluent, true);
    }
    public V1alpha1CodeRepositoryStatusBuilder(V1alpha1CodeRepositoryStatusFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new V1alpha1CodeRepositoryStatus(), validationEnabled);
    }
    public V1alpha1CodeRepositoryStatusBuilder(V1alpha1CodeRepositoryStatusFluent<?> fluent,V1alpha1CodeRepositoryStatus instance){
            this(fluent, instance, true);
    }
    public V1alpha1CodeRepositoryStatusBuilder(V1alpha1CodeRepositoryStatusFluent<?> fluent,V1alpha1CodeRepositoryStatus instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withServiceStatus(instance.getServiceStatus());

            fluent.withRepository(instance.getRepository());

            this.validationEnabled = validationEnabled; 
    }
    public V1alpha1CodeRepositoryStatusBuilder(V1alpha1CodeRepositoryStatus instance){
            this(instance,true);
    }
    public V1alpha1CodeRepositoryStatusBuilder(V1alpha1CodeRepositoryStatus instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withServiceStatus(instance.getServiceStatus());

            this.withRepository(instance.getRepository());

            this.validationEnabled = validationEnabled; 
    }

    public V1alpha1CodeRepositoryStatus build(){
            V1alpha1CodeRepositoryStatus buildable = new V1alpha1CodeRepositoryStatus();
            buildable.setServiceStatus(fluent.getServiceStatus());
            buildable.setRepository(fluent.getRepository());
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1alpha1CodeRepositoryStatusBuilder that = (V1alpha1CodeRepositoryStatusBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> devops-client-java-1.0.6.1-sources.jar: io/alauda/devops/java/client/models/V1alpha1CodeRepositoryStatusBuilder.java <==
package io.alauda.devops.java.client.models;

import io.alauda.devops.java.client.fluent.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class V1alpha1CodeRepositoryStatusBuilder extends V1alpha1CodeRepositoryStatusFluentImpl<V1alpha1CodeRepositoryStatusBuilder> implements VisitableBuilder<V1alpha1CodeRepositoryStatus,V1alpha1CodeRepositoryStatusBuilder>{

    V1alpha1CodeRepositoryStatusFluent<?> fluent;
    Boolean validationEnabled;

    public V1alpha1CodeRepositoryStatusBuilder(){
            this(true);
    }
    public V1alpha1CodeRepositoryStatusBuilder(Boolean validationEnabled){
            this(new V1alpha1CodeRepositoryStatus(), validationEnabled);
    }
    public V1alpha1CodeRepositoryStatusBuilder(V1alpha1CodeRepositoryStatusFluent<?> fluent){
            this(fluent, true);
    }
    public V1alpha1CodeRepositoryStatusBuilder(V1alpha1CodeRepositoryStatusFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new V1alpha1CodeRepositoryStatus(), validationEnabled);
    }
    public V1alpha1CodeRepositoryStatusBuilder(V1alpha1CodeRepositoryStatusFluent<?> fluent,V1alpha1CodeRepositoryStatus instance){
            this(fluent, instance, true);
    }
    public V1alpha1CodeRepositoryStatusBuilder(V1alpha1CodeRepositoryStatusFluent<?> fluent,V1alpha1CodeRepositoryStatus instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withConditions(instance.getConditions());

            fluent.withHttp(instance.getHttp());

            fluent.withLastUpdated(instance.getLastUpdated());

            fluent.withMessage(instance.getMessage());

            fluent.withPhase(instance.getPhase());

            fluent.withReason(instance.getReason());

            fluent.withRepository(instance.getRepository());

            this.validationEnabled = validationEnabled; 
    }
    public V1alpha1CodeRepositoryStatusBuilder(V1alpha1CodeRepositoryStatus instance){
            this(instance,true);
    }
    public V1alpha1CodeRepositoryStatusBuilder(V1alpha1CodeRepositoryStatus instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withConditions(instance.getConditions());

            this.withHttp(instance.getHttp());

            this.withLastUpdated(instance.getLastUpdated());

            this.withMessage(instance.getMessage());

            this.withPhase(instance.getPhase());

            this.withReason(instance.getReason());

            this.withRepository(instance.getRepository());

            this.validationEnabled = validationEnabled; 
    }

    public V1alpha1CodeRepositoryStatus build(){
            V1alpha1CodeRepositoryStatus buildable = new V1alpha1CodeRepositoryStatus();
            buildable.setConditions(fluent.getConditions());
            buildable.setHttp(fluent.getHttp());
            buildable.setLastUpdated(fluent.getLastUpdated());
            buildable.setMessage(fluent.getMessage());
            buildable.setPhase(fluent.getPhase());
            buildable.setReason(fluent.getReason());
            buildable.setRepository(fluent.getRepository());
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1alpha1CodeRepositoryStatusBuilder that = (V1alpha1CodeRepositoryStatusBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
